/*
** Module   : Cleanable.java
** Abstract : Defines an interface for tokens in the security context that
**            implement finalization.
**
** Copyright (c) 2004-2012, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ------------------Description-------------------
** 001 NVS 20050504   @21069 Created the initial version.
** 002 OM  20121016          Added comment description about how to avoid 
**                           issue #1577.
*/ 

package com.goldencode.p2j.security;

/**
 * Defines an interface for tokens in the security context that
 * implement finalization.
 * <p>
 * This interface defines just one method: cleanup(). Tokens that need
 * finalization should be instances of a class that implements this interface.
 * <p>
 * When it is time to finalize the token, its cleanup() method is called.
 *  
 * @author NVS
 * @version 1.0
 */
public interface Cleanable
{
   /**
    * The only method declared by the interface. It is called when it is time 
    * to finalize the token.  
    * <p>
    * <strong>Note</strong></br>
    * Do not use <code>ContextLocal</code> references in the cleanup() method 
    * implementation as, at the time of this call, the context-local variables 
    * are already deleted from the SecurityContext (by the 
    * <code>SecurityContext.cleanup()</code> code).
    */
   public void cleanup();
}
